@@ -6,8 +6,20 @@
         matchMedia("(prefers-color-scheme: dark)").matches &&
         !document.querySelector(".darkreader--fallback")
     ) {
-        const css =
-            'html, body, body :not(iframe):not(div[style^="position:absolute;top:0;left:-"]) { background-color: #181a1b !important; border-color: #776e62 !important; color: #e8e6e3 !important; } html, body { opacity: 1 !important; transition: none !important; }';
+        const css = [
+            "html, body, body :not(iframe) {",
+            "    background-color: #181a1b !important;",
+            "    border-color: #776e62 !important;",
+            "    color: #e8e6e3 !important;",
+            "}",
+            "html, body {",
+            "    opacity: 1 !important;",
+            "    transition: none !important;",
+            "}",
+            'div[style*="background-color: rgb(135, 135, 135)"] {',
+            "    background-color: #878787 !important;",
+            "}"
+        ].join("\n");
         const fallback = document.createElement("style");
         fallback.classList.add("darkreader");
         fallback.classList.add("darkreader--fallback");
